pub struct ReadRationing {
pub master_read_percent: u8,
/* private fields */
}Expand description
Read-write ratio controller: routes read requests to master (strong consistency read) or slave (weak consistency read) by ratio
Fields
master_read_percent: u80..=100, indicates what ratio of reads go to master 0 means all reads go to slave, 100 means all reads go to master
Implementations
Sourceimpl ReadRationing
impl ReadRationing
pub fn new(master_read_percent: u8) -> Self
Sourcepub fn default_slave_only() -> Self
pub fn default_slave_only() -> Self
Default 0% to master (all reads go to slave)
Sourcepub fn default_master_only() -> Self
pub fn default_master_only() -> Self
Default 100% to master (strong consistency read)
Sourcepub fn should_read_master(&self) -> bool
pub fn should_read_master(&self) -> bool
Decide whether this read request should go to master
Sourcepub fn set_percent(&mut self, percent: u8)
pub fn set_percent(&mut self, percent: u8)
Update the ratio (runtime hot update)